@@ -9,7 +9,9 @@ for Python 2.6/2.7.
 - itertools.count          (for Python 2.6, with step parameter)
 - subprocess.check_output  (for Python 2.6)
 - reprlib.recursive_repr   (for Python 2.6+)
+- functools.cmp_to_key     (for Python 2.6)
 """
+
 from __future__ import absolute_import
 
 import subprocess
@@ -777,7 +779,7 @@ class ChainMap(MutableMapping):
 
     # Py2 compatibility:
     __nonzero__ = __bool__
-        
+
     @recursive_repr()
     def __repr__(self):
         return '{0.__class__.__name__}({1})'.format(
@@ -815,7 +817,7 @@ class ChainMap(MutableMapping):
         try:
             del self.maps[0][key]
         except KeyError:
-            raise KeyError('Key not found in the first mapping: {!r}'.format(key))
+            raise KeyError('Key not found in the first mapping: {0!r}'.format(key))
 
     def popitem(self):
         'Remove and return an item pair from maps[0]. Raise KeyError is maps[0] is empty.'
@@ -829,7 +831,7 @@ class ChainMap(MutableMapping):
         try:
             return self.maps[0].pop(key, *args)
         except KeyError:
-            raise KeyError('Key not found in the first mapping: {!r}'.format(key))
+            raise KeyError('Key not found in the first mapping: {0!r}'.format(key))
 
     def clear(self):
         'Clear maps[0], leaving maps[1:] intact.'
@@ -881,6 +883,28 @@ def create_connection(address, timeout=_GLOBAL_DEFAULT_TIMEOUT,
     else:
         raise error("getaddrinfo returns an empty list")
 
+# Backport from Py2.7 for Py2.6:
+def cmp_to_key(mycmp):
+    """Convert a cmp= function into a key= function"""
+    class K(object):
+        __slots__ = ['obj']
+        def __init__(self, obj, *args):
+            self.obj = obj
+        def __lt__(self, other):
+            return mycmp(self.obj, other.obj) < 0
+        def __gt__(self, other):
+            return mycmp(self.obj, other.obj) > 0
+        def __eq__(self, other):
+            return mycmp(self.obj, other.obj) == 0
+        def __le__(self, other):
+            return mycmp(self.obj, other.obj) <= 0
+        def __ge__(self, other):
+            return mycmp(self.obj, other.obj) >= 0
+        def __ne__(self, other):
+            return mycmp(self.obj, other.obj) != 0
+        def __hash__(self):
+            raise TypeError('hash not implemented')
+    return K
 
 # Back up our definitions above in case they're useful
 _OrderedDict = OrderedDict
@@ -892,13 +916,19 @@ __count_elements = _count_elements
 _recursive_repr = recursive_repr
 _ChainMap = ChainMap
 _create_connection = create_connection
+_cmp_to_key = cmp_to_key
 
 # Overwrite the definitions above with the usual ones
 # from the standard library:
 if sys.version_info >= (2, 7):
     from collections import OrderedDict, Counter
-    from subprocess import check_output
     from itertools import count
+    from functools import cmp_to_key
+    try:
+        from subprocess import check_output
+    except ImportError:
+        # Not available. This happens with Google App Engine: see issue #231
+        pass
     from socket import create_connection
 
 if sys.version_info >= (3, 0):
